@@ -5,7 +5,7 @@ __email__ = "e@neural7.io"
 __copyright__ = "Copyright Neural7 2022, Big 5 Personality Traits"
 __credits__ = ["John A. Johnson", "Dhiru Kholia"]
 __license__ = "MIT"
-__version__ = "1.7.0"
+__version__ = "1.8.0"
 __status__ = "production"
 
 from ipipneo.utility import reverse_scored
@@ -252,16 +252,10 @@ class ReverseScoredCustom:
             raise BaseException("The key named (reverse_scored) was not found!")
 
         def is_reversed_custom(x: dict) -> dict:
-            x["id_select"] = (
-                reverse_scored(select=x["id_select"])
-                if x.get("reverse_scored") == 1
-                else x["id_select"]
-            )
+            x["id_select"] = reverse_scored(select=x["id_select"]) if x.get("reverse_scored") == 1 else x["id_select"]
             return x
 
-        return {
-            "answers": [is_reversed_custom(x=x) for x in answers.get("answers", [])]
-        }
+        return {"answers": [is_reversed_custom(x=x) for x in answers.get("answers", [])]}
 
 
 class ReverseScored120:
@@ -291,9 +285,7 @@ class ReverseScored120:
         if not any("id_select" in x for x in answers.get("answers", [])):
             raise BaseException("The key named (id_select) was not found!")
 
-        assert (
-            len(list(IPIP_NEO_ITEMS_REVERSED_120)) == 55
-        ), "The number of reverse items should be 55!"
+        assert len(list(IPIP_NEO_ITEMS_REVERSED_120)) == 55, "The number of reverse items should be 55!"
 
         def is_reversed_120(x: int, y: int) -> int:
             for i in IPIP_NEO_ITEMS_REVERSED_120:
@@ -302,13 +294,7 @@ class ReverseScored120:
             return y
 
         update = map(
-            (
-                lambda x: (
-                    x.__setitem__(
-                        "id_select", is_reversed_120(x["id_question"], x["id_select"])
-                    )
-                )
-            ),
+            (lambda x: (x.__setitem__("id_select", is_reversed_120(x["id_question"], x["id_select"])))),
             answers.get("answers"),
         )
         assert len(list(update)) == 120, "The update number should be 120!"
@@ -343,9 +329,7 @@ class ReverseScored300:
         if not any("id_select" in x for x in answers.get("answers", [])):
             raise BaseException("The key named (id_select) was not found!")
 
-        assert (
-            len(list(IPIP_NEO_ITEMS_REVERSED_300)) == 148
-        ), "The number of reverse items should be 148!"
+        assert len(list(IPIP_NEO_ITEMS_REVERSED_300)) == 148, "The number of reverse items should be 148!"
 
         def is_reversed_300(x: int, y: int) -> int:
             for i in IPIP_NEO_ITEMS_REVERSED_300:
@@ -354,13 +338,7 @@ class ReverseScored300:
             return y
 
         update = map(
-            (
-                lambda x: (
-                    x.__setitem__(
-                        "id_select", is_reversed_300(x["id_question"], x["id_select"])
-                    )
-                )
-            ),
+            (lambda x: (x.__setitem__("id_select", is_reversed_300(x["id_question"], x["id_select"])))),
             answers.get("answers"),
         )
         assert len(list(update)) == 300, "The update number should be 300!"
